reckon_db_tracker_group (reckon_db v1.6.0)
View SourceTracker group management for reckon-db
Uses pg (process groups) for managing tracker processes. Trackers receive notifications about subscription lifecycle events.
This module provides: - Process group management for tracker processes - Notification broadcasting for created/deleted/updated events
Features that can be tracked: - subscriptions: Subscription lifecycle - streams: Stream lifecycle - snapshots: Snapshot lifecycle
Summary
Functions
Generate the group key for a feature's trackers
Join one or more processes to the tracker group for a feature
Remove one or more processes from the tracker group
Get all member processes tracking a feature
Notify all trackers that a feature instance was created
Notify all trackers that a feature instance was deleted
Notify all trackers that a feature instance was updated
Types
Functions
Generate the group key for a feature's trackers
Join one or more processes to the tracker group for a feature
Remove one or more processes from the tracker group
Get all member processes tracking a feature
Notify all trackers that a feature instance was created
Notify all trackers that a feature instance was deleted
Notify all trackers that a feature instance was updated